@@ -77,16 +77,10 @@ for all configuration options:
                                     "hostname" => "localhost",
                                     "port"   => "3306"};
 
-  my $AssociationLoginParam = {     "driver" => "mysql",
-                                    "database" => "CUI_BIGRAMS_27JUL15",
-                                    "username" => "username",
-                                    "password" => "password",
-                                    "socket" => "/home/mysql/mysql.sock",
-                                    "hostname" => "localhost",
-                                    "port"   => "3306"};
 
 
-  my $interface = new SemMed::Interface($SemMedLoginParam, $AssociationLoginParam);
+
+  my $interface = new SemMed::Interface($SemMedLoginParam);
 
 =cut
 
@@ -99,7 +93,7 @@ use SemMed::Interface::DataAccess;
 
 use vars qw($VERSION);
 
-$VERSION = '0.03';
+$VERSION = '0.05';
 
 my $connection = "";
 my $gt = "";
@@ -139,8 +133,9 @@ description:
 
 input:
 
- $source_concept <- string containing the concept id of the cui to start seraching from
+ $source_concept <- string containing the concept id of the cui to start searching from
  $destination_concept <- string containing the concept id you are searching for
+ @includedPredicates <- List of predicates to include when searching for outgoing edges.
 
 output:
 
@@ -154,6 +149,15 @@ example:
 
  my $pathlength = $interface->findPathLength("C0018787", "C0027061");
 
+example:
+
+ #finds path length between Heart and Myocardial Infarction
+ use SemMed::Interface;
+ my $interface = new SemMed::Interface();
+ my @includedPredicates = ("TREATS", "CAUSES"); #limits BFS to paths that are associated with the predicates TREATS or CAUSES.
+
+ my $pathlength = $interface->findPathLength("C0018787", "C0027061", \@includedPredicates);
+
 
 =cut
 sub findPathLength{
@@ -161,7 +165,7 @@ sub findPathLength{
     my $self = shift;
     my $source_cui = shift;
     my $destination_cui = shift;
-   # return $gt->findPath($source_cui, $destination_cui, \@includedPredicates, \@excludedPredicates);
+    my $includedPredicates = shift;
     return $gt->findPath($source_cui, $destination_cui);
 }
 
@@ -247,10 +251,71 @@ sub getConnections {
 }
 
 
+=head3 getOverlappingConcepts
+description:
+  Gets the number of overlapping concepts in the neighboorhood of two given concepts
+input:
+ $concept_one <- string containing the concept id of the first concept
+ $concept_two <- string containing the concept id of the second concept
+output:
+ $numberOfOverlap  <- number of overlapping concepts in the neighboorhoods of the two given concepts
+
+example:
+  use SemMed::Interface;
+  my $interface = new SemMed::Interface();
+
+  my $overlap = $interface->getOverlappingConcepts("C0018787", "C0000932");
+S
+=cut
+
+sub getOverlappingConcepts{
+  my $self = shift;
+  my $concept_one = shift;
+  my $concept_two = shift;
+  my $includedPredicates = shift;
+
+  return $gt->getOverlappingConcepts($concept_one, $concept_two, $includedPredicates);
+
+}
 
 
+=head3 randomWalk
+description:
+  Simulates a random walk starting at $concept_one and ending at $concept_two
+input:
+ $concept_one <- string containing the concept id of the starting concept
+ $concept_two <- string containing the concept id of the ending concept
+output:
+ $stepsTaken  <- number of steps it took to reach $concept_two from $concept_one
 
+example:
+  use SemMed::Interface;
+  my $interface = new SemMed::Interface();
 
+  my $steps = $interface->randomWalk("C0018787", "C0000932");
+
+=cut
+
+sub randomWalk{
+  my $self = shift;
+  my $concept_one = shift;
+  my $concept_two = shift;
+  my $includedPredicates = shift;
+
+  my $currentVertex = $concept_one;
+  my $steps = 0;
+  while($currentVertex ne $concept_two){
+
+    $steps++;
+
+    my $randomNeighbor = $gt->getRandomNeighbor($currentVertex, $includedPredicates);
+    if($randomNeighbor){
+      $currentVertex = $randomNeighbor;
+    }else{exit;}
+  }
+
+  return $steps;
+}
 
 
 sub addIncludedPredicates{
