@@ -57,6 +57,11 @@ sub new {
 #OUTPUT: ARRAY OF PREDICATE objects whos source is SOURCE_CUI_OBJECT and destination is what was matched in DB.
 sub getPredicateConnections {
 
+    if(not $association){
+      print "Error: UMLS::Association not loaded";
+      exit;
+    }
+
     my $self = shift;
 
     my $cui = shift;
@@ -173,16 +178,55 @@ sub getCUI{
 
 
 
-
+#Gets outgoing predicates from inputed concept
+#INPUT: CUI
+#OUTPUT: Array holding predicate's and destination_cui's (predicate, destination_cui)
 sub getConnections {
   my $self = shift;
   my $concept = shift;
-  my $sth = $dbh->prepare("SELECT predicate, o_cui FROM DISTINCT_PREDICATION_AGGREGATE WHERE s_cui = '$concept'");
+  my $includedPredicates = shift;
+  my $query = "SELECT predicate, o_cui FROM DISTINCT_PREDICATION_AGGREGATE WHERE s_cui = '$concept'";
+
+  if($includedPredicates){
+      my $perm = " AND (";
+      foreach $pred ( @$includedPredicates){
+          $perm .= "predicate = '$pred' OR ";
+      }
+      substr($perm, -4) = ""; #remove extra OR
+      $perm .= ")";
+      $query .= $perm;
+  }
+
+  my $sth = $dbh->prepare($query);
   $sth->execute() or die $DBI::errstr;
-  @rows = $sth->fetchrow_array();
-  return \@rows;
+  $rows = $sth->fetchall_arrayref();
+  return $rows;
 }
 
+sub getBidirectionalConnections{
+  my $self = shift;
+  my $concept = shift;
+  my $includedPredicates = shift;
+  my $query = "SELECT s_cui, o_cui FROM DISTINCT_PREDICATION_AGGREGATE WHERE s_cui = '$concept' OR o_cui = '$concept'";
+
+  if($includedPredicates){
+      my $perm = " AND (";
+      foreach $pred ( @$includedPredicates){
+          $perm .= "predicate = '$pred' OR ";
+      }
+      substr($perm, -4) = ""; #remove extra OR
+      $perm .= ")";
+      $query .= $perm;
+  }
+
+  my $sth = $dbh->prepare($query);
+  $sth->execute() or die $DBI::errstr;
+  $rows = $sth->fetchall_arrayref();
+  return $rows;
+
+}
+
+
 
 #
 # OBTAIN SEMTYPE FROM CUI ID
