@@ -6,10 +6,10 @@
 #
 use strict;
 use warnings;
-use CUI;
-use Predicate;
-require DataAccess;
-require Heap::Priority;
+use SemMed::Interface::CUI;
+use SemMed::Interface::Predicate;
+use SemMed::Interface::DataAccess;
+use Heap::Priority;
 package GraphTraversal;
 
 
@@ -28,7 +28,7 @@ sub new{
 #-1 signifying no path was found. Path data in the returned CUI can be access through its methods (ie. $CUI->getPathLength())
 #Utilizes Dijktras for finding shortest path between CUI's
 
-#INPUT: SOURCE_CUI(string), DESTINATION_CUI(St$gt = new GraphTraversal();ring), WEIGHT_STATISTICAL_MEASURE(string)
+#INPUT: SOURCE_CUI(string), DESTINATION_CUI(String), WEIGHT_STATISTICAL_MEASURE(string)
 #OPTIONAL INPUT: , List of predicates to only include, List of Predicates to Ignore
 
 
@@ -119,7 +119,7 @@ sub findShortestPath{
 
 #
 #INPUT: SOURCE_CUI(string), DESTINATION_CUI(string)
-#OPTIONAL INPUT: , List of predicates to only include, List of Predicates to Ignore
+#OPTIONAL INPUT: List of predicates to only include
 #
 #OUTPUT: PathLength from SOURCE_CUI to DESTINATION_CUI
 #
@@ -129,7 +129,6 @@ sub findPath{
     my $startCui = shift; #String containing the start cui
     my $endCui = shift; #String containing the end cui
     my $includedPredicates = shift; #array reference to list of predicates to include
-    my $excludedPredicates = shift; #array reference to list of predicates to ignore
 
 
 
@@ -150,14 +149,12 @@ sub findPath{
             return -1;
         }
 
-        my @adjacentedges = $conn->getPredicateConnections($conn->getCUI($currentCUI), 1, $includedPredicates, $excludedPredicates);
-
+        my $adjacentedges = $conn->getConnections($currentCUI, $includedPredicates);
         #push new vertices to end of queue
-        foreach my $edge (@adjacentedges){
-            push @reachedCUI, $edge->getDestination()->getId();
+        foreach my $edge (@{$adjacentedges}){
+	          push @reachedCUI, @{$edge}[1];
             push @reachedLength, ($currentLength + 1);
         }
-
         #pop next vertex from queue
         $currentCUI = shift @reachedCUI;
         $currentLength = shift @reachedLength;
@@ -247,12 +244,12 @@ sub findPathString{
 
     while($currentCUI ne $endCui){
 
-        my @adjacentedges = $conn->getPredicateConnections($conn->getCUI($currentCUI), $measure, $includedPredicates, $excludedPredicates);
+        my $adjacentedges = $conn->getConnections($currentCUI);
 
         #push new vertices to end of queue
-        foreach my $edge (@adjacentedges){
-            push @reachedCUI, $edge->getDestination()->getId();
-            push @reachedString, ($currentString." ".$edge->getDestination()->getId());
+        foreach my $edge (@{$adjacentedges}){
+            push @reachedCUI, @{$edge}[1];
+            push @reachedString, ($currentString." ".@{$edge}[1]);
         }
 
         #pop next vertex from queue
@@ -264,10 +261,55 @@ sub findPathString{
 
     return $currentString;
 
+}
 
+#Finds overlap in outgoing concepts from two given concepts
+#
+#input: cui, cui
+#output: score <- integer denoting the number of overlapping concepts
+
+sub getOverlappingConcepts{
+  my $self = shift;
+  my $concept_one = shift;
+  my $concept_two = shift;
+  my $includedPredicates = shift;
+
+  my $concept_one_breadth = $conn->getConnections($concept_one, $includedPredicates);
+  my $concept_two_breadth = $conn->getConnections($concept_two, $includedPredicates);
+
+  my $overlapping_concepts = 0;
+  foreach my $edge (@{$concept_one_breadth}){
+    my $concept = @{$edge}[1];
+    foreach my $edge2 (@{$concept_two_breadth}){
+      if($concept eq @{$edge2}[1]){
+        $overlapping_concepts++;
+        last;
+      }
+    }
+  }
+  return $overlapping_concepts;
 
 
 }
 
+# a random neighboor of a given cui
+
+sub getRandomNeighbor{
+  my $self = shift;
+  my $concept = shift;
+  my $includedPredicates = shift;
+  my @neighbors = @{$conn->getBidirectionalConnections($concept, $includedPredicates)};
+  my @randomConnection = @{$neighbors[rand @neighbors]};
+
+  if($randomConnection[0] eq $concept){#our neighbor is the second element
+    return $randomConnection[1];
+  }else{
+    return $randomConnection[0];
+  }
+
+}
+
+
+
 
 1;
